@@ -21,7 +21,7 @@ import contextvars
 import json
 
 import structlog
-import toml
+import tomli
 import appdirs
 
 from .lib import nicelogger
@@ -156,8 +156,9 @@ def load_file(
   use_keymanager: bool,
 ) -> Tuple[Entries, Options]:
   try:
-    config = toml.load(file)
-  except (OSError, toml.TomlDecodeError) as e:
+    with open(file, 'rb') as f:
+      config = tomli.load(f)
+  except (OSError, tomli.TOMLDecodeError) as e:
     raise FileLoadError('version configuration file', file, e)
 
   ver_files: Optional[Tuple[Path, Path]] = None
@@ -237,7 +238,7 @@ class Dispatcher:
         mods[source] = mod, tasks
         config = source_configs.get(source)
         if config and getattr(mod, 'configure'):
-          mod.configure(config) # type: ignore
+          mod.configure(config)
       else:
         tasks = mods[source][1]
       tasks.append((name, entry))
@@ -245,7 +246,7 @@ class Dispatcher:
     ret = []
     for mod, tasks in mods.values():
       if hasattr(mod, 'Worker'):
-        worker_cls = mod.Worker # type: ignore
+        worker_cls = mod.Worker
       else:
         worker_cls = FunctionWorker
 
@@ -255,7 +256,7 @@ class Dispatcher:
         task_sem, result_q, tasks, keymanager,
       )
       if worker_cls is FunctionWorker:
-        func = mod.get_version # type: ignore
+        func = mod.get_version
         ctx.run(worker.initialize, func)
 
       ret.append(ctx.run(worker.run))
@@ -359,20 +360,22 @@ async def process_result(
   oldvers: VersData,
   result_q: Queue[RawResult],
   entry_waiter: EntryWaiter,
-) -> VersData:
+) -> Tuple[VersData, bool]:
   ret = {}
+  has_failures = False
   try:
     while True:
       r = await result_q.get()
       r1 = _process_result(r)
       if isinstance(r1, Exception):
         entry_waiter.set_exception(r.name, r1)
+        has_failures = True
         continue
       check_version_update(oldvers, r1.name, r1.version)
       entry_waiter.set_result(r1.name, r1.version)
       ret[r1.name] = r1.version
   except asyncio.CancelledError:
-    return ret
+    return ret, has_failures
 
 async def run_tasks(
   futures: Sequence[Awaitable[None]]
